[![Tests](https://github.com/RadostW/mdadiffusion/actions/workflows/tests.yml/badge.svg)](https://github.com/RadostW/mdadiffusion/actions/workflows/tests.yml)

# MinimumDissipationApproximation

Package for computing hydrodynamic size of elastic proteins (IDPs) in Minimum Dissipation Approximation and Kirkwood-Riesman approximation.
Relies on PyGRPY for approximations of mobility tensors.

# License

This software is MIT licensed

# How to cite

B. Cichocki, M. Rubin, A. Niedzwiecka and P. Szymczak *Diffusion coefficients of elastic 
macromolecules*; J. Fluid. Mech. (2019)

